==> java-git-0.0.1-sources.jar: io/github/andreyzebin/gitSql/git/RemoteOrigin.java <==
package io.github.andreyzebin.gitSql.git;


import io.github.zebin.javabash.process.TextTerminal;
import io.github.zebin.javabash.sandbox.BashUtils;
import io.github.zebin.javabash.sandbox.DirectoryTree;
import io.github.zebin.javabash.sandbox.FileManager;
import io.github.zebin.javabash.sandbox.WorkingDirectory;
import lombok.extern.slf4j.Slf4j;

import java.nio.file.Path;
import java.util.Objects;
import java.util.Optional;
import java.util.stream.Stream;

@Slf4j
public class RemoteOrigin extends AbstractVersionControl implements GitVersions {

    protected String gitUri;
    private final TextTerminal bash;
    private final GitAuth authStrategy;
    protected Path root;

    private final String branch;
    private String defaultBranch;

    private final Path home;
    private final GitConfigurations configurations;

    public RemoteOrigin(String gitUri, TextTerminal bash, GitAuth authStrategy) {
        this(gitUri, bash, authStrategy, null, new DefaultConfigurations(bash));
    }

    public RemoteOrigin(String gitUri, TextTerminal bash, GitAuth authStrategy, String branch) {
        this(gitUri, bash, authStrategy, branch, new DefaultConfigurations(bash));
    }

    public RemoteOrigin(
            String gitUri,
            TextTerminal bash,
            GitAuth authStrategy,
            String branch,
            GitConfigurations configurations
    ) {
        super(bash);
        this.branch = branch;
        this.gitUri = gitUri;
        this.bash = bash;
        this.authStrategy = authStrategy;
        this.home = configurations.getHomeTemporaryDir();
        this.configurations = configurations;
    }

    public LocalSource getLocal() {
        return new LocalSource(getRoot(), bash);
    }

    @Override
    public Optional<String> branch() {
        if (branch == null && defaultBranch == null) {
            defaultBranch = super.branch().orElse(null);
        }
        return Optional.ofNullable(branch)
                .or(() -> Optional.ofNullable(defaultBranch));
    }

    @Override
    public Optional<String> origin() {
        return Optional.of(gitUri);
    }

    @Override
    public void close() throws Exception {
        if (root != null) {
            BashUtils.lockDir(bash, () -> {
                log.debug("Cleaning up temporary git root...");
                bash.eval("cd " + BashUtils.encode(root.getParent()));
                bash.eval("rm -rf " + root.getFileName().toString());
                return 0;
            });
        }
    }

    public Stream<BranchHead> listBranches() {
        authStrategy.beforeRemote(bash);
        Stream<BranchHead> remoteBranches = GitBindings.getRemoteBranches(
                authStrategy.injectAuth(gitUri),
                bash,
                authStrategy.useAuthHeader()
        );
        authStrategy.afterRemote(bash);

        return remoteBranches;
    }

    @Override
    public Path getRoot() {
        if (root == null) {
            log.debug("Initializing Git root...");

            return BashUtils.lockDir(bash, () -> {
                String tempDirName = configurations.getTemporaryName(gitUri, branch);
                try {
                    bash.eval("cd " + BashUtils.encode(home));
                    bash.eval("mkdir -p " + tempDirName);
                    bash.eval("cd " + tempDirName);
                    authStrategy.beforeRemote(bash);

                    GitBindings.clone(
                            ".",
                            bash,
                            authStrategy.injectAuth(gitUri),
                            false,
                            authStrategy.useAuthHeader(),
                            branch
                    );
                    authStrategy.afterRemote(bash);

                    return root = home.resolve(tempDirName);
                } catch (Exception e) {
                    log.error("Error while loading from remote: ", e);
                    throw new RuntimeException(e);
                }
            });
        }
        return root;
    }

    @Override
    public void flush() {
        if (root != null) {
            BashUtils.lockDir(bash, () -> {
                bash.eval("cd " + BashUtils.encode(getRoot()));
                authStrategy.beforeRemote(bash);
                GitBindings.push(bash);
                authStrategy.afterRemote(bash);
                return 0;
            });
        }
    }

    @Override
    public void pull() {
        BashUtils.lockDir(bash, () -> {
            bash.eval("cd " + BashUtils.encode(getRoot()));
            authStrategy.beforeRemote(bash);
            GitBindings.pull(bash);
            authStrategy.afterRemote(bash);
            return 0;
        });
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RemoteOrigin that = (RemoteOrigin) o;
        return Objects.equals(gitUri, that.gitUri) && Objects.equals(branch, that.branch);
    }

    @Override
    public int hashCode() {
        return Objects.hash(gitUri, branch);
    }

}

==> java-git-0.0.2-sources.jar: io/github/andreyzebin/gitSql/git/RemoteOrigin.java <==
package io.github.andreyzebin.gitSql.git;


import io.github.zebin.javabash.process.TextTerminal;
import io.github.zebin.javabash.sandbox.BashUtils;
import lombok.extern.slf4j.Slf4j;

import java.nio.file.Path;
import java.util.Objects;
import java.util.function.Consumer;
import java.util.stream.Stream;

@Slf4j
public class RemoteOrigin extends AbstractClient {

    protected String gitUri;
    private final TextTerminal bash;
    private final GitAuth authStrategy;
    protected Path root;

    private final String branch;
    private String defaultBranch;

    private final Path home;
    private final GitConfigurations configurations;

    public RemoteOrigin(String gitUri, TextTerminal bash, GitAuth authStrategy) {
        this(gitUri, bash, authStrategy, null, new DefaultConfigurations(bash));
    }

    public RemoteOrigin(String gitUri, TextTerminal bash, GitAuth authStrategy, String branch) {
        this(gitUri, bash, authStrategy, branch, new DefaultConfigurations(bash));
    }

    public RemoteOrigin(
            String gitUri,
            TextTerminal bash,
            GitAuth authStrategy,
            String branch,
            GitConfigurations configurations
    ) {

        super(bash);
        this.branch = branch;
        this.gitUri = gitUri;
        this.bash = bash;
        this.authStrategy = authStrategy;
        this.home = configurations.getHomeTemporaryDir();
        this.configurations = configurations;
    }

    public LocalSource getLocal() {
        return new LocalSource(getRoot(), bash);
    }

    @Override
    public void close() throws Exception {
        if (root != null) {
            BashUtils.lockDir(bash, () -> {
                log.debug("Cleaning up temporary git root...");
                bash.eval("cd " + BashUtils.encode(root.getParent()));
                bash.eval("rm -rf " + root.getFileName().toString());
                return 0;
            });
        }
    }

    public void withTerminal(Consumer<TextTerminal> evals) throws Exception {
        if (root != null) {
            BashUtils.lockDir(bash, () -> {
                bash.eval("cd " + BashUtils.encode(getRoot()));
                evals.accept(bash);

                return 0;
            });
        }
    }

    public Stream<BranchHead> listBranches() {
        authStrategy.beforeRemote(bash);
        Stream<BranchHead> remoteBranches = GitBindings.getRemoteBranches(
                authStrategy.injectAuth(gitUri),
                bash,
                authStrategy.useAuthHeader()
        );
        authStrategy.afterRemote(bash);

        return remoteBranches;
    }

    @Override
    public Path getRoot() {
        if (root == null) {
            log.debug("Initializing Git root...");

            return BashUtils.lockDir(bash, () -> {
                String tempDirName = configurations.getTemporaryName(gitUri, branch);
                try {
                    bash.eval("mkdir -p " + BashUtils.encode(home));
                    bash.eval("cd " + BashUtils.encode(home));
                    bash.eval("mkdir -p " + tempDirName);
                    bash.eval("cd " + tempDirName);
                    authStrategy.beforeRemote(bash);

                    GitBindings.clone(
                            ".",
                            bash,
                            authStrategy.injectAuth(gitUri),
                            false,
                            authStrategy.useAuthHeader(),
                            null
                    );
                    authStrategy.afterRemote(bash);

                    return root = home.resolve(tempDirName);
                } catch (Exception e) {
                    log.error("Error while loading from remote: ", e);
                    throw new RuntimeException(e);
                }
            });
        }
        return root;
    }

    @Override
    public void push() {
        if (root != null) {
            BashUtils.lockDir(bash, () -> {
                bash.eval("cd " + BashUtils.encode(getRoot()));
                authStrategy.beforeRemote(bash);
                GitBindings.push(bash);
                authStrategy.afterRemote(bash);
                return 0;
            });
        }
    }

    @Override
    public void setOrigin(String origin) {

    }

    @Override
    public void pull() {
        BashUtils.lockDir(bash, () -> {
            bash.eval("cd " + BashUtils.encode(getRoot()));
            authStrategy.beforeRemote(bash);
            GitBindings.pullAll(bash);
            authStrategy.afterRemote(bash);
            return 0;
        });
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RemoteOrigin that = (RemoteOrigin) o;
        return Objects.equals(gitUri, that.gitUri) && Objects.equals(branch, that.branch);
    }

    @Override
    public int hashCode() {
        return Objects.hash(gitUri, branch);
    }

}
